@@ -7,25 +7,25 @@
 
 #include "nm-active-connection.h"
 
-#include "nm-libnm-core-intern/nm-common-macros.h"
+#include "libnm-core-aux-intern/nm-common-macros.h"
 #include "nm-dbus-interface.h"
 #include "devices/nm-device.h"
 #include "settings/nm-settings-connection.h"
 #include "nm-simple-connection.h"
 #include "nm-auth-utils.h"
 #include "nm-auth-manager.h"
-#include "nm-libnm-core-intern/nm-auth-subject.h"
+#include "libnm-core-aux-intern/nm-auth-subject.h"
 #include "nm-keep-alive.h"
 #include "NetworkManagerUtils.h"
-#include "nm-core-internal.h"
+#include "libnm-core-intern/nm-core-internal.h"
 
 #define AUTH_CALL_ID_SHARED_WIFI_PERMISSION_FAILED ((NMAuthManagerCallId *) GINT_TO_POINTER(1))
 
 typedef struct _NMActiveConnectionPrivate {
     NMDBusTrackObjPath settings_connection;
-    NMConnection *     applied_connection;
-    char *             specific_object;
-    NMDevice *         device;
+    NMConnection      *applied_connection;
+    char              *specific_object;
+    NMDevice          *device;
 
     guint64 version_id;
 
@@ -48,7 +48,7 @@ typedef struct _NMActiveConnectionPrivate {
      * reason never changes. */
     NMActivationReason activation_reason : 4;
 
-    NMAuthSubject *     subject;
+    NMAuthSubject      *subject;
     NMActiveConnection *master;
 
     NMActiveConnection *parent;
@@ -107,7 +107,7 @@ static const GDBusSignalInfo             signal_info_state_changed;
 static void check_master_ready(NMActiveConnection *self);
 static void _device_cleanup(NMActiveConnection *self);
 static void _settings_connection_flags_changed(NMSettingsConnection *settings_connection,
-                                               NMActiveConnection *  self);
+                                               NMActiveConnection   *self);
 static void _set_activation_type_managed(NMActiveConnection *self);
 
 static void auth_complete(NMActiveConnection *self, gboolean result, const char *message);
@@ -208,12 +208,12 @@ _set_settings_connection(NMActiveConnection *self, NMSettingsConnection *sett_co
     if (sett_conn) {
         g_signal_connect(sett_conn,
                          NM_SETTINGS_CONNECTION_UPDATED_INTERNAL,
-                         (GCallback) _settings_connection_updated,
+                         G_CALLBACK(_settings_connection_updated),
                          self);
         if (nm_active_connection_get_activation_type(self) == NM_ACTIVATION_TYPE_EXTERNAL)
             g_signal_connect(sett_conn,
                              NM_SETTINGS_CONNECTION_FLAGS_CHANGED,
-                             (GCallback) _settings_connection_flags_changed,
+                             G_CALLBACK(_settings_connection_flags_changed),
                              self);
     }
 
@@ -239,7 +239,7 @@ emit_state_changed(NMActiveConnection *self, guint state, guint reason)
 }
 
 void
-nm_active_connection_set_state(NMActiveConnection *          self,
+nm_active_connection_set_state(NMActiveConnection           *self,
                                NMActiveConnectionState       new_state,
                                NMActiveConnectionStateReason reason)
 {
@@ -314,9 +314,9 @@ nm_active_connection_set_state(NMActiveConnection *          self,
 }
 
 void
-nm_active_connection_set_state_fail(NMActiveConnection *          self,
+nm_active_connection_set_state_fail(NMActiveConnection           *self,
                                     NMActiveConnectionStateReason reason,
-                                    const char *                  error_desc)
+                                    const char                   *error_desc)
 {
     NMActiveConnectionState s;
 
@@ -350,7 +350,7 @@ nm_active_connection_get_state_flags(NMActiveConnection *self)
 }
 
 void
-nm_active_connection_set_state_flags_full(NMActiveConnection *   self,
+nm_active_connection_set_state_flags_full(NMActiveConnection    *self,
                                           NMActivationStateFlags state_flags,
                                           NMActivationStateFlags mask)
 {
@@ -432,7 +432,7 @@ static void
 _set_applied_connection_take(NMActiveConnection *self, NMConnection *applied_connection)
 {
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
-    NMSettingConnection *      s_con;
+    NMSettingConnection       *s_con;
     NMActivationStateFlags     flags_val = 0;
 
     nm_assert(NM_IS_CONNECTION(applied_connection));
@@ -458,7 +458,7 @@ _set_applied_connection_take(NMActiveConnection *self, NMConnection *applied_con
 }
 
 void
-nm_active_connection_set_settings_connection(NMActiveConnection *  self,
+nm_active_connection_set_settings_connection(NMActiveConnection   *self,
                                              NMSettingsConnection *sett_conn)
 {
     NMActiveConnectionPrivate *priv;
@@ -489,7 +489,7 @@ nm_active_connection_set_settings_connection(NMActiveConnection *  self,
 }
 
 gboolean
-nm_active_connection_has_unmodified_applied_connection(NMActiveConnection *  self,
+nm_active_connection_has_unmodified_applied_connection(NMActiveConnection   *self,
                                                        NMSettingCompareFlags compare_flags)
 {
     NMActiveConnectionPrivate *priv;
@@ -516,11 +516,6 @@ nm_active_connection_clear_secrets(NMActiveConnection *self)
 
     priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
 
-    if (nm_settings_connection_has_unmodified_applied_connection(priv->settings_connection.obj,
-                                                                 priv->applied_connection,
-                                                                 NM_SETTING_COMPARE_FLAG_NONE)) {
-        nm_settings_connection_clear_secrets(priv->settings_connection.obj, FALSE, FALSE);
-    }
     nm_connection_clear_secrets(priv->applied_connection);
 }
 
@@ -620,13 +615,13 @@ nm_active_connection_get_device(NMActiveConnection *self)
 }
 
 static void
-device_state_changed(NMDevice *          device,
+device_state_changed(NMDevice           *device,
                      NMDeviceState       new_state,
                      NMDeviceState       old_state,
                      NMDeviceStateReason reason,
                      gpointer            user_data)
 {
-    NMActiveConnection *       self = NM_ACTIVE_CONNECTION(user_data);
+    NMActiveConnection        *self = NM_ACTIVE_CONNECTION(user_data);
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
 
     /* When already deactivated or before activation, device state changes are useless */
@@ -646,9 +641,9 @@ device_state_changed(NMDevice *          device,
 static void
 device_master_changed(GObject *object, GParamSpec *pspec, gpointer user_data)
 {
-    NMDevice *              device = NM_DEVICE(object);
-    NMActiveConnection *    self   = NM_ACTIVE_CONNECTION(user_data);
-    NMActiveConnection *    master;
+    NMDevice               *device = NM_DEVICE(object);
+    NMActiveConnection     *self   = NM_ACTIVE_CONNECTION(user_data);
+    NMActiveConnection     *master;
     NMActiveConnectionState master_state;
 
     if (NM_ACTIVE_CONNECTION(nm_device_get_act_request(device)) != self)
@@ -672,7 +667,7 @@ static void
 device_metered_changed(GObject *object, GParamSpec *pspec, gpointer user_data)
 {
     NMActiveConnection *self   = (NMActiveConnection *) user_data;
-    NMDevice *          device = NM_DEVICE(object);
+    NMDevice           *device = NM_DEVICE(object);
 
     g_return_if_fail(NM_IS_ACTIVE_CONNECTION(self));
     g_signal_emit(self, signals[DEVICE_METERED_CHANGED], 0, nm_device_get_metered(device));
@@ -682,7 +677,8 @@ gboolean
 nm_active_connection_set_device(NMActiveConnection *self, NMDevice *device)
 {
     NMActiveConnectionPrivate *priv;
-    gs_unref_object NMDevice *old_device = NULL;
+    gs_unref_object NMDevice  *old_device = NULL;
+    NMMetered                  old_metered, new_metered;
 
     g_return_val_if_fail(NM_IS_ACTIVE_CONNECTION(self), FALSE);
     g_return_val_if_fail(!device || NM_IS_DEVICE(device), FALSE);
@@ -700,6 +696,8 @@ nm_active_connection_set_device(NMActiveConnection *self, NMDevice *device)
           device);
 
     old_device = priv->device ? g_object_ref(priv->device) : NULL;
+
+    old_metered = old_device ? nm_device_get_metered(old_device) : NM_METERED_UNKNOWN;
     _device_cleanup(self);
 
     if (device) {
@@ -735,7 +733,11 @@ nm_active_connection_set_device(NMActiveConnection *self, NMDevice *device)
     }
     _notify(self, PROP_INT_DEVICE);
 
+    new_metered = priv->device ? nm_device_get_metered(priv->device) : NM_METERED_UNKNOWN;
+
     g_signal_emit(self, signals[DEVICE_CHANGED], 0, priv->device, old_device);
+    if (new_metered != old_metered)
+        g_signal_emit(self, signals[DEVICE_METERED_CHANGED], 0, new_metered);
 
     _notify(self, PROP_DEVICES);
 
@@ -808,7 +810,7 @@ check_master_ready(NMActiveConnection *self)
 static void
 master_state_cb(NMActiveConnection *master, GParamSpec *pspec, gpointer user_data)
 {
-    NMActiveConnection *       self         = NM_ACTIVE_CONNECTION(user_data);
+    NMActiveConnection        *self         = NM_ACTIVE_CONNECTION(user_data);
     NMActiveConnectionPrivate *priv         = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
     NMActiveConnectionState    master_state = nm_active_connection_get_state(master);
 
@@ -856,7 +858,7 @@ nm_active_connection_set_master(NMActiveConnection *self, NMActiveConnection *ma
     priv->master = g_object_ref(master);
     g_signal_connect(priv->master,
                      "notify::" NM_ACTIVE_CONNECTION_STATE,
-                     (GCallback) master_state_cb,
+                     G_CALLBACK(master_state_cb),
                      self);
 
     check_master_ready(self);
@@ -888,7 +890,7 @@ _set_activation_type(NMActiveConnection *self, NMActivationType activation_type)
         if (activation_type == NM_ACTIVATION_TYPE_EXTERNAL)
             g_signal_connect(priv->settings_connection.obj,
                              NM_SETTINGS_CONNECTION_FLAGS_CHANGED,
-                             (GCallback) _settings_connection_flags_changed,
+                             G_CALLBACK(_settings_connection_flags_changed),
                              self);
         else
             g_signal_handlers_disconnect_by_func(priv->settings_connection.obj,
@@ -959,7 +961,7 @@ nm_active_connection_get_keep_alive(NMActiveConnection *self)
 
 static void
 _settings_connection_flags_changed(NMSettingsConnection *settings_connection,
-                                   NMActiveConnection *  self)
+                                   NMActiveConnection   *self)
 {
     NMDevice *device;
 
@@ -1006,7 +1008,7 @@ parent_destroyed(gpointer user_data, GObject *parent)
 static void
 parent_state_cb(NMActiveConnection *parent_ac, GParamSpec *pspec, gpointer user_data)
 {
-    NMActiveConnection *    self         = user_data;
+    NMActiveConnection     *self         = user_data;
     NMActiveConnectionState parent_state = nm_active_connection_get_state(parent_ac);
 
     if (parent_state < NM_ACTIVE_CONNECTION_STATE_ACTIVATED)
@@ -1023,7 +1025,7 @@ unwatch_parent(NMActiveConnection *self, gboolean unref)
 {
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
 
-    g_signal_handlers_disconnect_by_func(priv->parent, (GCallback) parent_state_cb, self);
+    g_signal_handlers_disconnect_by_func(priv->parent, G_CALLBACK(parent_state_cb), self);
     if (unref)
         g_object_weak_unref((GObject *) priv->parent, parent_destroyed, self);
     priv->parent = NULL;
@@ -1047,7 +1049,7 @@ nm_active_connection_set_parent(NMActiveConnection *self, NMActiveConnection *pa
     priv->parent = parent;
     g_signal_connect(priv->parent,
                      "notify::" NM_ACTIVE_CONNECTION_STATE,
-                     (GCallback) parent_state_cb,
+                     G_CALLBACK(parent_state_cb),
                      self);
     g_object_weak_ref((GObject *) priv->parent, parent_destroyed, self);
 }
@@ -1057,7 +1059,7 @@ nm_active_connection_set_parent(NMActiveConnection *self, NMActiveConnection *pa
 static void
 auth_complete(NMActiveConnection *self, gboolean result, const char *message)
 {
-    NMActiveConnectionPrivate *      priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
+    NMActiveConnectionPrivate       *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
     NMActiveConnectionAuthResultFunc result_func;
     gpointer                         user_data;
 
@@ -1090,15 +1092,15 @@ auth_complete_keep_alive(NMActiveConnection *self, gboolean result, const char *
 }
 
 static void
-auth_done(NMAuthManager *      auth_mgr,
+auth_done(NMAuthManager       *auth_mgr,
           NMAuthManagerCallId *auth_call_id,
           gboolean             is_authorized,
           gboolean             is_challenge,
-          GError *             error,
+          GError              *error,
           gpointer             user_data)
 
 {
-    NMActiveConnection *       self = NM_ACTIVE_CONNECTION(user_data);
+    NMActiveConnection        *self = NM_ACTIVE_CONNECTION(user_data);
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
     NMAuthCallResult           result;
 
@@ -1161,14 +1163,14 @@ auth_done(NMAuthManager *      auth_mgr,
  * activation request.
  */
 void
-nm_active_connection_authorize(NMActiveConnection *             self,
-                               NMConnection *                   initial_connection,
+nm_active_connection_authorize(NMActiveConnection              *self,
+                               NMConnection                    *initial_connection,
                                NMActiveConnectionAuthResultFunc result_func,
                                gpointer                         user_data)
 {
     NMActiveConnectionPrivate *priv            = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
-    const char *               wifi_permission = NULL;
-    NMConnection *             connection;
+    const char                *wifi_permission = NULL;
+    NMConnection              *connection;
 
     g_return_if_fail(result_func);
     g_return_if_fail(!priv->auth.call_id_network_control);
@@ -1268,10 +1270,10 @@ _device_cleanup(NMActiveConnection *self)
 static void
 get_property(GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
-    NMActiveConnection *       self = NM_ACTIVE_CONNECTION(object);
+    NMActiveConnection        *self = NM_ACTIVE_CONNECTION(object);
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
-    char **                    strv;
-    NMDevice *                 master_device = NULL;
+    char                     **strv;
+    NMDevice                  *master_device = NULL;
 
     switch (prop_id) {
     /* note that while priv->settings_connection.obj might not be set initially,
@@ -1361,11 +1363,11 @@ get_property(GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 static void
 set_property(GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
-    NMActiveConnection *       self = (NMActiveConnection *) object;
+    NMActiveConnection        *self = (NMActiveConnection *) object;
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
-    const char *               tmp;
-    NMSettingsConnection *     sett_conn;
-    NMConnection *             acon;
+    const char                *tmp;
+    NMSettingsConnection      *sett_conn;
+    NMConnection              *acon;
     int                        i;
 
     switch (prop_id) {
@@ -1475,7 +1477,7 @@ nm_active_connection_init(NMActiveConnection *self)
 static void
 constructed(GObject *object)
 {
-    NMActiveConnection *       self = (NMActiveConnection *) object;
+    NMActiveConnection        *self = (NMActiveConnection *) object;
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
 
     G_OBJECT_CLASS(nm_active_connection_parent_class)->constructed(object);
@@ -1510,7 +1512,7 @@ constructed(GObject *object)
 static void
 dispose(GObject *object)
 {
-    NMActiveConnection *       self = NM_ACTIVE_CONNECTION(object);
+    NMActiveConnection        *self = NM_ACTIVE_CONNECTION(object);
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
 
     nm_assert(!c_list_is_linked(&self->active_connections_lst));
@@ -1527,7 +1529,7 @@ dispose(GObject *object)
     _device_cleanup(self);
 
     if (priv->master) {
-        g_signal_handlers_disconnect_by_func(priv->master, (GCallback) master_state_cb, self);
+        g_signal_handlers_disconnect_by_func(priv->master, G_CALLBACK(master_state_cb), self);
     }
     g_clear_object(&priv->master);
 
@@ -1542,7 +1544,7 @@ dispose(GObject *object)
 static void
 finalize(GObject *object)
 {
-    NMActiveConnection *       self = NM_ACTIVE_CONNECTION(object);
+    NMActiveConnection        *self = NM_ACTIVE_CONNECTION(object);
     NMActiveConnectionPrivate *priv = NM_ACTIVE_CONNECTION_GET_PRIVATE(self);
 
     nm_dbus_track_obj_path_set(&priv->settings_connection, NULL, FALSE);
@@ -1560,60 +1562,54 @@ static const GDBusSignalInfo signal_info_state_changed = NM_DEFINE_GDBUS_SIGNAL_
 static const NMDBusInterfaceInfoExtended interface_info_active_connection = {
     .parent = NM_DEFINE_GDBUS_INTERFACE_INFO_INIT(
         NM_DBUS_INTERFACE_ACTIVE_CONNECTION,
-        .signals    = NM_DEFINE_GDBUS_SIGNAL_INFOS(&nm_signal_info_property_changed_legacy,
-                                                &signal_info_state_changed, ),
+        .signals    = NM_DEFINE_GDBUS_SIGNAL_INFOS(&signal_info_state_changed, ),
         .properties = NM_DEFINE_GDBUS_PROPERTY_INFOS(
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Connection",
-                                                             "o",
-                                                             NM_ACTIVE_CONNECTION_CONNECTION),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("SpecificObject",
-                                                             "o",
-                                                             NM_ACTIVE_CONNECTION_SPECIFIC_OBJECT),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Id", "s", NM_ACTIVE_CONNECTION_ID),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Uuid",
-                                                             "s",
-                                                             NM_ACTIVE_CONNECTION_UUID),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Type",
-                                                             "s",
-                                                             NM_ACTIVE_CONNECTION_TYPE),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Devices",
-                                                             "ao",
-                                                             NM_ACTIVE_CONNECTION_DEVICES),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("State",
-                                                             "u",
-                                                             NM_ACTIVE_CONNECTION_STATE),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("StateFlags",
-                                                             "u",
-                                                             NM_ACTIVE_CONNECTION_STATE_FLAGS),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Default",
-                                                             "b",
-                                                             NM_ACTIVE_CONNECTION_DEFAULT),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Ip4Config",
-                                                             "o",
-                                                             NM_ACTIVE_CONNECTION_IP4_CONFIG),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Dhcp4Config",
-                                                             "o",
-                                                             NM_ACTIVE_CONNECTION_DHCP4_CONFIG),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Default6",
-                                                             "b",
-                                                             NM_ACTIVE_CONNECTION_DEFAULT6),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Ip6Config",
-                                                             "o",
-                                                             NM_ACTIVE_CONNECTION_IP6_CONFIG),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Dhcp6Config",
-                                                             "o",
-                                                             NM_ACTIVE_CONNECTION_DHCP6_CONFIG),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Vpn", "b", NM_ACTIVE_CONNECTION_VPN),
-            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE_L("Master",
-                                                             "o",
-                                                             NM_ACTIVE_CONNECTION_MASTER), ), ),
-    .legacy_property_changed = TRUE,
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Connection",
+                                                           "o",
+                                                           NM_ACTIVE_CONNECTION_CONNECTION),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("SpecificObject",
+                                                           "o",
+                                                           NM_ACTIVE_CONNECTION_SPECIFIC_OBJECT),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Id", "s", NM_ACTIVE_CONNECTION_ID),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Uuid", "s", NM_ACTIVE_CONNECTION_UUID),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Type", "s", NM_ACTIVE_CONNECTION_TYPE),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Devices",
+                                                           "ao",
+                                                           NM_ACTIVE_CONNECTION_DEVICES),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("State",
+                                                           "u",
+                                                           NM_ACTIVE_CONNECTION_STATE),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("StateFlags",
+                                                           "u",
+                                                           NM_ACTIVE_CONNECTION_STATE_FLAGS),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Default",
+                                                           "b",
+                                                           NM_ACTIVE_CONNECTION_DEFAULT),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Ip4Config",
+                                                           "o",
+                                                           NM_ACTIVE_CONNECTION_IP4_CONFIG),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Dhcp4Config",
+                                                           "o",
+                                                           NM_ACTIVE_CONNECTION_DHCP4_CONFIG),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Default6",
+                                                           "b",
+                                                           NM_ACTIVE_CONNECTION_DEFAULT6),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Ip6Config",
+                                                           "o",
+                                                           NM_ACTIVE_CONNECTION_IP6_CONFIG),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Dhcp6Config",
+                                                           "o",
+                                                           NM_ACTIVE_CONNECTION_DHCP6_CONFIG),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Vpn", "b", NM_ACTIVE_CONNECTION_VPN),
+            NM_DEFINE_DBUS_PROPERTY_INFO_EXTENDED_READABLE("Master",
+                                                           "o",
+                                                           NM_ACTIVE_CONNECTION_MASTER), ), ),
 };
 
 static void
 nm_active_connection_class_init(NMActiveConnectionClass *ac_class)
 {
-    GObjectClass *     object_class      = G_OBJECT_CLASS(ac_class);
+    GObjectClass      *object_class      = G_OBJECT_CLASS(ac_class);
     NMDBusObjectClass *dbus_object_class = NM_DBUS_OBJECT_CLASS(ac_class);
 
     g_type_class_add_private(ac_class, sizeof(NMActiveConnectionPrivate));
