@@ -37,7 +37,9 @@ gboolean
 nmtstp_is_root_test(void)
 {
     g_assert(_nmtstp_setup_platform_func);
-    return _nmtstp_setup_platform_func == nm_linux_platform_setup;
+    return NM_IN_SET(_nmtstp_setup_platform_func,
+                     nm_linux_platform_setup,
+                     nm_linux_platform_setup_with_tc_cache);
 }
 
 gboolean
@@ -92,7 +94,7 @@ nmtstp_platform_ip_address_find(NMPlatform *self, int ifindex, int addr_family,
     const int                  IS_IPv4 = NM_IS_IPv4(addr_family);
     const NMPlatformIPAddress *found   = NULL;
     NMDedupMultiIter           iter;
-    const NMPObject *          obj;
+    const NMPObject           *obj;
     NMPLookup                  lookup;
 
     g_assert(NM_IS_PLATFORM(self));
@@ -100,7 +102,11 @@ nmtstp_platform_ip_address_find(NMPlatform *self, int ifindex, int addr_family,
     nm_assert_addr_family(addr_family);
     nm_assert(addr);
 
-    nmp_lookup_init_object(&lookup, NMP_OBJECT_TYPE_IP_ADDRESS(IS_IPv4), ifindex);
+    if (ifindex > 0)
+        nmp_lookup_init_object(&lookup, NMP_OBJECT_TYPE_IP_ADDRESS(IS_IPv4), ifindex);
+    else
+        nmp_lookup_init_obj_type(&lookup, NMP_OBJECT_TYPE_IP_ADDRESS(IS_IPv4));
+
     nm_platform_iter_obj_for_each (&iter, self, &lookup, &obj) {
         const NMPlatformIPAddress *a = NMP_OBJECT_CAST_IP_ADDRESS(obj);
 
@@ -130,9 +136,9 @@ typedef struct {
 } IPAddressesAssertData;
 
 void
-_nmtstp_platform_ip_addresses_assert(const char *       filename,
+_nmtstp_platform_ip_addresses_assert(const char        *filename,
                                      int                lineno,
-                                     NMPlatform *       self,
+                                     NMPlatform        *self,
                                      int                ifindex,
                                      gboolean           force_exact_4,
                                      gboolean           force_exact_6,
@@ -174,8 +180,8 @@ _nmtstp_platform_ip_addresses_assert(const char *       filename,
     }
 
     for (IS_IPv4 = 1; IS_IPv4 >= 0; IS_IPv4--) {
-        const int         addr_family           = IS_IPv4 ? AF_INET : AF_INET6;
-        gs_unref_ptrarray GPtrArray *plat_addrs = NULL;
+        const int                    addr_family = IS_IPv4 ? AF_INET : AF_INET6;
+        gs_unref_ptrarray GPtrArray *plat_addrs  = NULL;
         NMPLookup                    lookup;
         guint                        j;
 
@@ -280,7 +286,7 @@ nmtstp_platform_ip4_route_delete(NMPlatform *platform,
 }
 
 gboolean
-nmtstp_platform_ip6_route_delete(NMPlatform *    platform,
+nmtstp_platform_ip6_route_delete(NMPlatform     *platform,
                                  int             ifindex,
                                  struct in6_addr network,
                                  guint8          plen,
@@ -309,11 +315,11 @@ nmtstp_platform_ip6_route_delete(NMPlatform *    platform,
 /*****************************************************************************/
 
 SignalData *
-add_signal_full(const char *               name,
+add_signal_full(const char                *name,
                 NMPlatformSignalChangeType change_type,
                 GCallback                  callback,
                 int                        ifindex,
-                const char *               ifname)
+                const char                *ifname)
 {
     SignalData *data = g_new0(SignalData, 1);
 
@@ -446,18 +452,18 @@ _free_signal(const char *file, int line, const char *func, SignalData *data)
 }
 
 void
-link_callback(NMPlatform *    platform,
+link_callback(NMPlatform     *platform,
               int             obj_type_i,
               int             ifindex,
               NMPlatformLink *received,
               int             change_type_i,
-              SignalData *    data)
+              SignalData     *data)
 {
     const NMPObjectType              obj_type    = obj_type_i;
     const NMPlatformSignalChangeType change_type = change_type_i;
     NMPLookup                        lookup;
     NMDedupMultiIter                 iter;
-    const NMPlatformLink *           cached;
+    const NMPlatformLink            *cached;
 
     g_assert_cmpint(obj_type, ==, NMP_OBJECT_TYPE_LINK);
     g_assert(received);
@@ -520,11 +526,11 @@ _ip4_route_get(NMPlatform *platform,
                int         plen,
                guint32     metric,
                guint8      tos,
-               guint *     out_c_exists)
+               guint      *out_c_exists)
 {
     NMDedupMultiIter          iter;
     NMPLookup                 lookup;
-    const NMPObject *         o = NULL;
+    const NMPObject          *o = NULL;
     guint                     c;
     const NMPlatformIP4Route *r = NULL;
 
@@ -604,18 +610,18 @@ nmtstp_ip4_route_get(NMPlatform *platform,
 /*****************************************************************************/
 
 static const NMPlatformIP6Route *
-_ip6_route_get(NMPlatform *           platform,
+_ip6_route_get(NMPlatform            *platform,
                int                    ifindex,
                const struct in6_addr *network,
                guint                  plen,
                guint32                metric,
                const struct in6_addr *src,
                guint8                 src_plen,
-               guint *                out_c_exists)
+               guint                 *out_c_exists)
 {
     NMDedupMultiIter          iter;
     NMPLookup                 lookup;
-    const NMPObject *         o = NULL;
+    const NMPObject          *o = NULL;
     guint                     c;
     const NMPlatformIP6Route *r = NULL;
 
@@ -637,12 +643,12 @@ _ip6_route_get(NMPlatform *           platform,
 }
 
 const NMPlatformIP6Route *
-_nmtstp_assert_ip6_route_exists(const char *           file,
+_nmtstp_assert_ip6_route_exists(const char            *file,
                                 guint                  line,
-                                const char *           func,
-                                NMPlatform *           platform,
+                                const char            *func,
+                                NMPlatform            *platform,
                                 int                    c_exists,
-                                const char *           ifname,
+                                const char            *ifname,
                                 const struct in6_addr *network,
                                 guint                  plen,
                                 guint32                metric,
@@ -685,7 +691,7 @@ _nmtstp_assert_ip6_route_exists(const char *           file,
 }
 
 const NMPlatformIP6Route *
-nmtstp_ip6_route_get(NMPlatform *           platform,
+nmtstp_ip6_route_get(NMPlatform            *platform,
                      int                    ifindex,
                      const struct in6_addr *network,
                      guint                  plen,
@@ -725,7 +731,7 @@ typedef struct {
 } WaitForSignalData;
 
 static void
-_wait_for_signal_cb(NMPlatform *    platform,
+_wait_for_signal_cb(NMPlatform     *platform,
                     int             obj_type_i,
                     int             ifindex,
                     NMPlatformLink *plink,
@@ -1014,7 +1020,7 @@ nmtstp_ip_address_assert_lifetime(const NMPlatformIPAddress *addr,
 /*****************************************************************************/
 
 static void
-_ip_address_add(NMPlatform *    platform,
+_ip_address_add(NMPlatform     *platform,
                 gboolean        external_command,
                 gboolean        is_v4,
                 int             ifindex,
@@ -1024,7 +1030,7 @@ _ip_address_add(NMPlatform *    platform,
                 guint32         lifetime,
                 guint32         preferred,
                 guint32         flags,
-                const char *    label)
+                const char     *label)
 {
     gint64 end_time;
 
@@ -1033,7 +1039,7 @@ _ip_address_add(NMPlatform *    platform,
     _init_platform(&platform, external_command);
 
     if (external_command) {
-        const char *  ifname;
+        const char   *ifname;
         gs_free char *s_valid     = NULL;
         gs_free char *s_preferred = NULL;
         gs_free char *s_label     = NULL;
@@ -1191,7 +1197,7 @@ nmtstp_ip4_address_add(NMPlatform *platform,
 }
 
 void
-nmtstp_ip6_address_add(NMPlatform *    platform,
+nmtstp_ip6_address_add(NMPlatform     *platform,
                        gboolean        external_command,
                        int             ifindex,
                        struct in6_addr address,
@@ -1215,7 +1221,7 @@ nmtstp_ip6_address_add(NMPlatform *    platform,
 }
 
 void
-nmtstp_ip4_route_add(NMPlatform *     platform,
+nmtstp_ip4_route_add(NMPlatform      *platform,
                      int              ifindex,
                      NMIPConfigSource source,
                      in_addr_t        network,
@@ -1241,7 +1247,7 @@ nmtstp_ip4_route_add(NMPlatform *     platform,
 }
 
 void
-nmtstp_ip6_route_add(NMPlatform *     platform,
+nmtstp_ip6_route_add(NMPlatform      *platform,
                      int              ifindex,
                      NMIPConfigSource source,
                      struct in6_addr  network,
@@ -1269,7 +1275,7 @@ nmtstp_ip6_route_add(NMPlatform *     platform,
 /*****************************************************************************/
 
 static void
-_ip_address_del(NMPlatform *    platform,
+_ip_address_del(NMPlatform     *platform,
                 gboolean        external_command,
                 gboolean        is_v4,
                 int             ifindex,
@@ -1386,7 +1392,7 @@ nmtstp_ip4_address_del(NMPlatform *platform,
 }
 
 void
-nmtstp_ip6_address_del(NMPlatform *    platform,
+nmtstp_ip6_address_del(NMPlatform     *platform,
                        gboolean        external_command,
                        int             ifindex,
                        struct in6_addr address,
@@ -1413,15 +1419,58 @@ nmtstp_ip6_address_del(NMPlatform *    platform,
     }                                                                                       \
     G_STMT_END
 
+/* Due to rounding errors with clock_t_to_jiffies()/jiffies_to_clock_t(), kernel cannot
+ * store all requested values. That means, when we try to configure a bridge with
+ * the @requested values, the actually configured settings are slightly off, as
+ * @kernel.
+ *
+ * This function takes @requested and returns it as @dst output. All fields
+ * that might be mangled by kernel (according to @kernel) are adjusted. The
+ * result is almost identical to @requested, but some fields might be adjusted
+ * to their @kernel value. */
+const NMPlatformLnkBridge *
+nmtstp_link_bridge_normalize_jiffies_time(const NMPlatformLnkBridge *requested,
+                                          const NMPlatformLnkBridge *kernel,
+                                          NMPlatformLnkBridge       *dst)
+{
+    g_assert(requested);
+    g_assert(dst);
+    g_assert(kernel);
+
+    if (dst != requested)
+        *dst = *requested;
+
+#define _normalize_field(dst, kernel, field)                                         \
+    G_STMT_START                                                                     \
+    {                                                                                \
+        (dst)->field = nmtstp_normalize_jiffies_time((dst)->field, (kernel)->field); \
+    }                                                                                \
+    G_STMT_END
+
+    _normalize_field(dst, kernel, forward_delay);
+    _normalize_field(dst, kernel, hello_time);
+    _normalize_field(dst, kernel, max_age);
+    _normalize_field(dst, kernel, ageing_time);
+    _normalize_field(dst, kernel, mcast_last_member_interval);
+    _normalize_field(dst, kernel, mcast_membership_interval);
+    _normalize_field(dst, kernel, mcast_querier_interval);
+    _normalize_field(dst, kernel, mcast_query_interval);
+    _normalize_field(dst, kernel, mcast_query_response_interval);
+    _normalize_field(dst, kernel, mcast_startup_query_interval);
+
+    return dst;
+}
+
 const NMPlatformLink *
-nmtstp_link_bridge_add(NMPlatform *               platform,
+nmtstp_link_bridge_add(NMPlatform                *platform,
                        gboolean                   external_command,
-                       const char *               name,
+                       const char                *name,
                        const NMPlatformLnkBridge *lnk)
 {
-    const NMPlatformLink *     pllink = NULL;
+    const NMPlatformLink      *pllink = NULL;
     const NMPlatformLnkBridge *ll     = NULL;
-    int                        r      = 0;
+    NMPlatformLnkBridge        lnk_normalized;
+    int                        r = 0;
 
     g_assert(nm_utils_ifname_valid_kernel(name, NULL));
 
@@ -1542,10 +1591,9 @@ nmtstp_link_bridge_add(NMPlatform *               platform,
 
     ll = NMP_OBJECT_CAST_LNK_BRIDGE(NMP_OBJECT_UP_CAST(pllink)->_link.netlink.lnk);
 
-    /* account for roundtrip rounding error with clock_t_to_jiffies()/jiffies_to_clock_t(). */
-    g_assert_cmpint(lnk->forward_delay, >=, ll->forward_delay - 1);
-    g_assert_cmpint(lnk->forward_delay, <=, ll->forward_delay);
+    lnk = nmtstp_link_bridge_normalize_jiffies_time(lnk, ll, &lnk_normalized);
 
+    g_assert_cmpint(lnk->forward_delay, ==, ll->forward_delay);
     g_assert_cmpint(lnk->hello_time, ==, ll->hello_time);
     g_assert_cmpint(lnk->max_age, ==, ll->max_age);
     g_assert_cmpint(lnk->ageing_time, ==, ll->ageing_time);
@@ -1642,9 +1690,9 @@ nmtstp_link_dummy_add(NMPlatform *platform, gboolean external_command, const cha
 }
 
 const NMPlatformLink *
-nmtstp_link_gre_add(NMPlatform *            platform,
+nmtstp_link_gre_add(NMPlatform             *platform,
                     gboolean                external_command,
-                    const char *            name,
+                    const char             *name,
                     const NMPlatformLnkGre *lnk)
 {
     const NMPlatformLink *pllink = NULL;
@@ -1662,7 +1710,7 @@ nmtstp_link_gre_add(NMPlatform *            platform,
 
     if (external_command) {
         gs_free char *dev = NULL;
-        char *        obj, *type;
+        char         *obj, *type;
 
         if (lnk->parent_ifindex)
             dev =
@@ -1693,9 +1741,9 @@ nmtstp_link_gre_add(NMPlatform *            platform,
 }
 
 const NMPlatformLink *
-nmtstp_link_ip6tnl_add(NMPlatform *               platform,
+nmtstp_link_ip6tnl_add(NMPlatform                *platform,
                        gboolean                   external_command,
-                       const char *               name,
+                       const char                *name,
                        const NMPlatformLnkIp6Tnl *lnk)
 {
     const NMPlatformLink *pllink = NULL;
@@ -1716,7 +1764,7 @@ nmtstp_link_ip6tnl_add(NMPlatform *               platform,
 
     if (external_command) {
         gs_free char *dev = NULL;
-        const char *  mode;
+        const char   *mode;
 
         if (lnk->parent_ifindex)
             dev =
@@ -1759,9 +1807,9 @@ nmtstp_link_ip6tnl_add(NMPlatform *               platform,
 }
 
 const NMPlatformLink *
-nmtstp_link_ip6gre_add(NMPlatform *               platform,
+nmtstp_link_ip6gre_add(NMPlatform                *platform,
                        gboolean                   external_command,
-                       const char *               name,
+                       const char                *name,
                        const NMPlatformLnkIp6Tnl *lnk)
 {
     const NMPlatformLink *pllink = NULL;
@@ -1818,9 +1866,9 @@ nmtstp_link_ip6gre_add(NMPlatform *               platform,
 }
 
 const NMPlatformLink *
-nmtstp_link_ipip_add(NMPlatform *             platform,
+nmtstp_link_ipip_add(NMPlatform              *platform,
                      gboolean                 external_command,
-                     const char *             name,
+                     const char              *name,
                      const NMPlatformLnkIpIp *lnk)
 {
     const NMPlatformLink *pllink = NULL;
@@ -1861,9 +1909,9 @@ nmtstp_link_ipip_add(NMPlatform *             platform,
 }
 
 const NMPlatformLink *
-nmtstp_link_macvlan_add(NMPlatform *                platform,
+nmtstp_link_macvlan_add(NMPlatform                 *platform,
                         gboolean                    external_command,
-                        const char *                name,
+                        const char                 *name,
                         int                         parent,
                         const NMPlatformLnkMacvlan *lnk)
 {
@@ -1881,7 +1929,7 @@ nmtstp_link_macvlan_add(NMPlatform *                platform,
 
     if (external_command) {
         const char *dev;
-        char *      modes[] = {
+        char       *modes[] = {
             [MACVLAN_MODE_BRIDGE]   = "bridge",
             [MACVLAN_MODE_VEPA]     = "vepa",
             [MACVLAN_MODE_PRIVATE]  = "private",
@@ -1910,9 +1958,9 @@ nmtstp_link_macvlan_add(NMPlatform *                platform,
 }
 
 const NMPlatformLink *
-nmtstp_link_sit_add(NMPlatform *            platform,
+nmtstp_link_sit_add(NMPlatform             *platform,
                     gboolean                external_command,
-                    const char *            name,
+                    const char             *name,
                     const NMPlatformLnkSit *lnk)
 {
     const NMPlatformLink *pllink = NULL;
@@ -1957,11 +2005,11 @@ nmtstp_link_sit_add(NMPlatform *            platform,
 }
 
 const NMPlatformLink *
-nmtstp_link_tun_add(NMPlatform *            platform,
+nmtstp_link_tun_add(NMPlatform             *platform,
                     gboolean                external_command,
-                    const char *            name,
+                    const char             *name,
                     const NMPlatformLnkTun *lnk,
-                    int *                   out_fd)
+                    int                    *out_fd)
 {
     const NMPlatformLink *pllink = NULL;
     int                   err;
@@ -2022,11 +2070,11 @@ nmtstp_link_tun_add(NMPlatform *            platform,
 }
 
 const NMPlatformLink *
-nmtstp_link_vrf_add(NMPlatform *            platform,
+nmtstp_link_vrf_add(NMPlatform             *platform,
                     gboolean                external_command,
-                    const char *            name,
+                    const char             *name,
                     const NMPlatformLnkVrf *lnk,
-                    gboolean *              out_not_supported)
+                    gboolean               *out_not_supported)
 {
     const NMPlatformLink *pllink = NULL;
     int                   r      = 0;
@@ -2059,9 +2107,9 @@ nmtstp_link_vrf_add(NMPlatform *            platform,
 }
 
 const NMPlatformLink *
-nmtstp_link_vxlan_add(NMPlatform *              platform,
+nmtstp_link_vxlan_add(NMPlatform               *platform,
                       gboolean                  external_command,
-                      const char *              name,
+                      const char               *name,
                       const NMPlatformLnkVxlan *lnk)
 {
     const NMPlatformLink *pllink = NULL;
@@ -2184,7 +2232,7 @@ nmtstp_link_delete(NMPlatform *platform,
     gint64                end_time;
     const NMPlatformLink *pllink;
     gboolean              success;
-    gs_free char *        name_copy = NULL;
+    gs_free char         *name_copy = NULL;
 
     external_command = nmtstp_run_command_check_external(external_command);
 
@@ -2246,9 +2294,9 @@ nmtstp_link_set_updown(NMPlatform *platform, gboolean external_command, int ifin
         nmtstp_run_command_check("ip link set %s %s", ifname, up ? "up" : "down");
     } else {
         if (up)
-            g_assert(nm_platform_link_set_up(platform, ifindex, NULL));
+            g_assert(nm_platform_link_change_flags(platform, ifindex, IFF_UP, TRUE) >= 0);
         else
-            g_assert(nm_platform_link_set_down(platform, ifindex));
+            g_assert(nm_platform_link_change_flags(platform, ifindex, IFF_UP, FALSE) >= 0);
     }
 
     /* Let's wait until we get the result */
@@ -2609,9 +2657,9 @@ main(int argc, char **argv)
 struct _NMTstpAcdDefender {
     int        ifindex;
     in_addr_t  ip_addr;
-    NAcd *     nacd;
+    NAcd      *nacd;
     NAcdProbe *probe;
-    GSource *  source;
+    GSource   *source;
     gint8      announce_started;
 };
 
@@ -2652,9 +2700,13 @@ _l3_acd_nacd_event(int fd, GIOCondition condition, gpointer user_data)
                   NM_HASH_OBFUSCATE_PTR(defender),
                   NM_ETHER_ADDR_FORMAT_VAL((const NMEtherAddr *) event->defended.sender));
             break;
+        case N_ACD_EVENT_DOWN:
+            /* Not sure why this sometimes happens. But this is only the test stub, ignore it. */
+            _LOGT("acd-defender[" NM_HASH_OBFUSCATE_PTR_FMT "]: link down event received",
+                  NM_HASH_OBFUSCATE_PTR(defender));
+            break;
         case N_ACD_EVENT_USED:
         case N_ACD_EVENT_CONFLICT:
-        case N_ACD_EVENT_DOWN:
         default:
             g_assert_not_reached();
             break;
@@ -2665,11 +2717,11 @@ _l3_acd_nacd_event(int fd, GIOCondition condition, gpointer user_data)
 NMTstpAcdDefender *
 nmtstp_acd_defender_new(int ifindex, in_addr_t ip_addr, const NMEtherAddr *mac_addr)
 {
-    NMTstpAcdDefender *                                defender;
-    nm_auto(n_acd_config_freep) NAcdConfig *           config       = NULL;
-    nm_auto(n_acd_unrefp) NAcd *                       nacd         = NULL;
+    NMTstpAcdDefender                                 *defender;
+    nm_auto(n_acd_config_freep) NAcdConfig            *config       = NULL;
+    nm_auto(n_acd_unrefp) NAcd                        *nacd         = NULL;
     nm_auto(n_acd_probe_config_freep) NAcdProbeConfig *probe_config = NULL;
-    NAcdProbe *                                        probe        = NULL;
+    NAcdProbe                                         *probe        = NULL;
     int                                                fd;
     int                                                r;
     char                                               sbuf_addr[NM_UTILS_INET_ADDRSTRLEN];
