@@ -10,17 +10,17 @@
 
 #include <stdlib.h>
 
-#include "nm-glib-aux/nm-str-buf.h"
-#include "nm-core-internal.h"
+#include "libnm-glib-aux/nm-str-buf.h"
+#include "libnm-core-intern/nm-core-internal.h"
 #include "nm-supplicant-settings-verify.h"
 #include "nm-setting.h"
-#include "nm-libnm-core-intern/nm-auth-subject.h"
+#include "libnm-core-aux-intern/nm-auth-subject.h"
 #include "NetworkManagerUtils.h"
 #include "nm-utils.h"
 #include "nm-setting-ip4-config.h"
 
 typedef struct {
-    char *         value;
+    char          *value;
     guint32        len;
     NMSupplOptType type;
 } ConfigOption;
@@ -28,8 +28,8 @@ typedef struct {
 /*****************************************************************************/
 
 typedef struct {
-    GHashTable *   config;
-    GHashTable *   blobs;
+    GHashTable    *config;
+    GHashTable    *blobs;
     NMSupplCapMask capabilities;
     guint32        ap_scan;
     bool           fast_required : 1;
@@ -63,7 +63,7 @@ NMSupplicantConfig *
 nm_supplicant_config_new(NMSupplCapMask capabilities)
 {
     NMSupplicantConfigPrivate *priv;
-    NMSupplicantConfig *       self;
+    NMSupplicantConfig        *self;
 
     self = g_object_new(NM_TYPE_SUPPLICANT_CONFIG, NULL);
     priv = NM_SUPPLICANT_CONFIG_GET_PRIVATE(self);
@@ -96,16 +96,16 @@ nm_supplicant_config_init(NMSupplicantConfig *self)
 
 static gboolean
 nm_supplicant_config_add_option_with_type(NMSupplicantConfig *self,
-                                          const char *        key,
-                                          const char *        value,
+                                          const char         *key,
+                                          const char         *value,
                                           gint32              len,
                                           NMSupplOptType      opt_type,
-                                          const char *        display_value,
-                                          GError **           error)
+                                          const char         *display_value,
+                                          GError            **error)
 {
     NMSupplicantConfigPrivate *priv;
-    ConfigOption *             old_opt;
-    ConfigOption *             opt;
+    ConfigOption              *old_opt;
+    ConfigOption              *opt;
     NMSupplOptType             type;
 
     g_return_val_if_fail(NM_IS_SUPPLICANT_CONFIG(self), FALSE);
@@ -124,7 +124,7 @@ nm_supplicant_config_add_option_with_type(NMSupplicantConfig *self,
         type = nm_supplicant_settings_verify_setting(key, value, len);
         if (type == NM_SUPPL_OPT_TYPE_INVALID) {
             gs_free char *str_free = NULL;
-            const char *  str;
+            const char   *str;
 
             str = nm_utils_buf_utf8safe_escape(value,
                                                len,
@@ -178,11 +178,11 @@ nm_supplicant_config_add_option_with_type(NMSupplicantConfig *self,
 
 static gboolean
 nm_supplicant_config_add_option(NMSupplicantConfig *self,
-                                const char *        key,
-                                const char *        value,
+                                const char         *key,
+                                const char         *value,
                                 gint32              len,
-                                const char *        display_value,
-                                GError **           error)
+                                const char         *display_value,
+                                GError            **error)
 {
     return nm_supplicant_config_add_option_with_type(self,
                                                      key,
@@ -195,16 +195,16 @@ nm_supplicant_config_add_option(NMSupplicantConfig *self,
 
 static gboolean
 nm_supplicant_config_add_blob(NMSupplicantConfig *self,
-                              const char *        key,
-                              GBytes *            value,
-                              const char *        blobid,
-                              GError **           error)
+                              const char         *key,
+                              GBytes             *value,
+                              const char         *blobid,
+                              GError            **error)
 {
     NMSupplicantConfigPrivate *priv;
-    ConfigOption *             old_opt;
-    ConfigOption *             opt;
+    ConfigOption              *old_opt;
+    ConfigOption              *opt;
     NMSupplOptType             type;
-    const guint8 *             data;
+    const guint8              *data;
     gsize                      data_len;
 
     g_return_val_if_fail(NM_IS_SUPPLICANT_CONFIG(self), FALSE);
@@ -256,14 +256,14 @@ nm_supplicant_config_add_blob(NMSupplicantConfig *self,
 
 static gboolean
 nm_supplicant_config_add_blob_for_connection(NMSupplicantConfig *self,
-                                             GBytes *            field,
-                                             const char *        name,
-                                             const char *        con_uid,
-                                             GError **           error)
+                                             GBytes             *field,
+                                             const char         *name,
+                                             const char         *con_uid,
+                                             GError            **error)
 {
     if (field && g_bytes_get_size(field)) {
         gs_free char *uid = NULL;
-        char *        p;
+        char         *p;
 
         uid = g_strdup_printf("%s-%s", con_uid, name);
         for (p = uid; *p; p++) {
@@ -317,8 +317,8 @@ nm_supplicant_config_to_variant(NMSupplicantConfig *self)
     NMSupplicantConfigPrivate *priv;
     GVariantBuilder            builder;
     GHashTableIter             iter;
-    ConfigOption *             option;
-    const char *               key;
+    ConfigOption              *option;
+    const char                *key;
 
     g_return_val_if_fail(NM_IS_SUPPLICANT_CONFIG(self), NULL);
 
@@ -334,11 +334,10 @@ nm_supplicant_config_to_variant(NMSupplicantConfig *self)
             break;
         case NM_SUPPL_OPT_TYPE_BYTES:
         case NM_SUPPL_OPT_TYPE_UTF8:
-            g_variant_builder_add(
-                &builder,
-                "{sv}",
-                key,
-                g_variant_new_fixed_array(G_VARIANT_TYPE_BYTE, option->value, option->len, 1));
+            g_variant_builder_add(&builder,
+                                  "{sv}",
+                                  key,
+                                  nm_g_variant_new_ay((const guint8 *) option->value, option->len));
             break;
         case NM_SUPPL_OPT_TYPE_KEYWORD:
         case NM_SUPPL_OPT_TYPE_STRING:
@@ -365,8 +364,8 @@ wifi_freqs_to_string(gboolean bg_band)
 {
     static const char *str_2ghz = NULL;
     static const char *str_5ghz = NULL;
-    const char **      f_p;
-    const char *       f;
+    const char       **f_p;
+    const char        *f;
 
     f_p = bg_band ? &str_2ghz : &str_5ghz;
 
@@ -375,7 +374,7 @@ again:
 
     if (G_UNLIKELY(!f)) {
         nm_auto_str_buf NMStrBuf strbuf = NM_STR_BUF_INIT(400, FALSE);
-        const guint *            freqs;
+        const guint             *freqs;
         int                      i;
 
         freqs = bg_band ? nm_utils_wifi_2ghz_freqs() : nm_utils_wifi_5ghz_freqs();
@@ -398,8 +397,8 @@ again:
 
 gboolean
 nm_supplicant_config_add_setting_macsec(NMSupplicantConfig *self,
-                                        NMSettingMacsec *   setting,
-                                        GError **           error)
+                                        NMSettingMacsec    *setting,
+                                        GError            **error)
 {
     const char *value;
     char        buf[32];
@@ -418,7 +417,7 @@ nm_supplicant_config_add_setting_macsec(NMSupplicantConfig *self,
 
     port = nm_setting_macsec_get_port(setting);
     if (port > 0 && port < 65534) {
-        snprintf(buf, sizeof(buf), "%d", port);
+        g_snprintf(buf, sizeof(buf), "%d", port);
         if (!nm_supplicant_config_add_option(self, "macsec_port", buf, -1, NULL, error))
             return FALSE;
     }
@@ -468,16 +467,16 @@ nm_supplicant_config_add_setting_macsec(NMSupplicantConfig *self,
 
 gboolean
 nm_supplicant_config_add_setting_wireless(NMSupplicantConfig *self,
-                                          NMSettingWireless * setting,
+                                          NMSettingWireless  *setting,
                                           guint32             fixed_freq,
-                                          GError **           error)
+                                          GError            **error)
 {
     NMSupplicantConfigPrivate *priv;
     gboolean                   is_adhoc, is_ap, is_mesh;
-    const char *               mode, *band;
+    const char                *mode, *band;
     guint32                    channel;
-    GBytes *                   ssid;
-    const char *               bssid;
+    GBytes                    *ssid;
+    const char                *bssid;
 
     g_return_val_if_fail(NM_IS_SUPPLICANT_CONFIG(self), FALSE);
     g_return_val_if_fail(setting != NULL, FALSE);
@@ -585,9 +584,9 @@ nm_supplicant_config_add_setting_wireless(NMSupplicantConfig *self,
 gboolean
 nm_supplicant_config_add_bgscan(NMSupplicantConfig *self, NMConnection *connection, GError **error)
 {
-    NMSettingWireless *        s_wifi;
+    NMSettingWireless         *s_wifi;
     NMSettingWirelessSecurity *s_wsec;
-    const char *               bgscan;
+    const char                *bgscan;
 
     s_wifi = nm_connection_get_setting_wireless(connection);
     g_assert(s_wifi);
@@ -633,11 +632,11 @@ nm_supplicant_config_add_bgscan(NMSupplicantConfig *self, NMConnection *connecti
 
 static gboolean
 add_string_val(NMSupplicantConfig *self,
-               const char *        field,
-               const char *        name,
+               const char         *field,
+               const char         *name,
                gboolean            ucase,
-               const char *        display_value,
-               GError **           error)
+               const char         *display_value,
+               GError            **error)
 {
     if (field) {
         gs_free char *value = NULL;
@@ -667,12 +666,12 @@ add_string_val(NMSupplicantConfig *self,
                             display_value,                                                \
                             error)                                                        \
     ({                                                                                    \
-        typeof(*(setting)) *_setting = (setting);                                         \
-        gboolean            _success = TRUE;                                              \
+        typeof(setting) _setting = (setting);                                             \
+        gboolean        _success = TRUE;                                                  \
                                                                                           \
         if (nm_setting_##setting_name##_get_num_##field_plural(_setting)) {               \
             const char _separator = (separator);                                          \
-            GString *  _str       = g_string_new(NULL);                                   \
+            GString   *_str       = g_string_new(NULL);                                   \
             guint      _k, _n;                                                            \
                                                                                           \
             _n = nm_setting_##setting_name##_get_num_##field_plural(_setting);            \
@@ -728,10 +727,10 @@ wep128_passphrase_hash(const char *input, gsize input_len, guint8 *digest /* 13
 
 static gboolean
 add_wep_key(NMSupplicantConfig *self,
-            const char *        key,
-            const char *        name,
+            const char         *key,
+            const char         *name,
             NMWepKeyType        wep_type,
-            GError **           error)
+            GError            **error)
 {
     gsize key_len;
 
@@ -802,26 +801,35 @@ add_wep_key(NMSupplicantConfig *self,
 }
 
 gboolean
-nm_supplicant_config_add_setting_wireless_security(NMSupplicantConfig *          self,
-                                                   NMSettingWirelessSecurity *   setting,
-                                                   NMSetting8021x *              setting_8021x,
-                                                   const char *                  con_uuid,
+nm_supplicant_config_add_setting_wireless_security(NMSupplicantConfig           *self,
+                                                   NMSettingWirelessSecurity    *setting,
+                                                   NMSetting8021x               *setting_8021x,
+                                                   const char                   *con_uuid,
+                                                   const char                   *mode,
                                                    guint32                       mtu,
                                                    NMSettingWirelessSecurityPmf  pmf,
                                                    NMSettingWirelessSecurityFils fils,
-                                                   GError **                     error)
+                                                   GError                      **error)
 {
-    NMSupplicantConfigPrivate *priv             = NM_SUPPLICANT_CONFIG_GET_PRIVATE(self);
+    NMSupplicantConfigPrivate    *priv          = NM_SUPPLICANT_CONFIG_GET_PRIVATE(self);
     nm_auto_free_gstring GString *key_mgmt_conf = NULL;
-    const char *                  key_mgmt, *auth_alg;
-    const char *                  psk;
-    gboolean                      set_pmf;
+    const char                   *key_mgmt, *auth_alg;
+    const char                   *psk;
+    gboolean                      set_pmf, wps_disabled;
+    gboolean                      is_ap;
 
     g_return_val_if_fail(NM_IS_SUPPLICANT_CONFIG(self), FALSE);
     g_return_val_if_fail(setting != NULL, FALSE);
     g_return_val_if_fail(con_uuid != NULL, FALSE);
     g_return_val_if_fail(!error || !*error, FALSE);
 
+    /* Currently wpa_supplicant doesn't support FT in AP mode. Even
+     * if it did, it  would require additional parameters as the nas
+     * identifier and the mobility domain. Therefore we disable all
+     * FT key-mgmts in AP mode.
+     */
+    is_ap = nm_streq0(mode, NM_SETTING_WIRELESS_MODE_AP);
+
     /* Check if we actually support FILS */
     if (!_get_capability(priv, NM_SUPPL_CAP_TYPE_FILS)) {
         if (fils == NM_SETTING_WIRELESS_SECURITY_FILS_REQUIRED) {
@@ -835,58 +843,110 @@ nm_supplicant_config_add_setting_wireless_security(NMSupplicantConfig *
     }
 
     key_mgmt      = nm_setting_wireless_security_get_key_mgmt(setting);
-    key_mgmt_conf = g_string_new(key_mgmt);
-    if (nm_streq(key_mgmt, "wpa-psk")) {
-        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF))
-            g_string_append(key_mgmt_conf, " wpa-psk-sha256");
-        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_FT))
-            g_string_append(key_mgmt_conf, " ft-psk");
-        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_SAE)) {
-            g_string_append(key_mgmt_conf, " sae");
-            if (_get_capability(priv, NM_SUPPL_CAP_TYPE_FT))
-                g_string_append(key_mgmt_conf, " ft-sae");
-        }
-    } else if (nm_streq(key_mgmt, "wpa-eap")) {
-        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF)) {
-            g_string_append(key_mgmt_conf, " wpa-eap-sha256");
+    key_mgmt_conf = g_string_new("");
 
+    if (nm_streq(key_mgmt, "none")) {
+        g_string_append(key_mgmt_conf, "NONE");
+
+    } else if (nm_streq(key_mgmt, "ieee8021x")) {
+        g_string_append(key_mgmt_conf, "IEEE8021X");
+
+    } else if (nm_streq(key_mgmt, "owe")) {
+        pmf = NM_SETTING_WIRELESS_SECURITY_PMF_REQUIRED;
+
+        g_string_append(key_mgmt_conf, "OWE");
+
+    } else if (nm_streq(key_mgmt, "wpa-psk")) {
+        if (pmf != NM_SETTING_WIRELESS_SECURITY_PMF_REQUIRED)
+            g_string_append(key_mgmt_conf, "WPA-PSK");
+        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF))
+            g_string_append(key_mgmt_conf, " WPA-PSK-SHA256");
+        if (!is_ap && _get_capability(priv, NM_SUPPL_CAP_TYPE_FT))
+            g_string_append(key_mgmt_conf, " FT-PSK");
+
+        /* For NM "key-mgmt=wpa-psk" doesn't strictly mean WPA1/wPA2 only,
+         * but also allows WPA3 (SAE), so that existing connections can
+         * benefit from the improved security when the AP gets upgraded.
+         *
+         * According to WPA3_Specification_v3.0 section 2.3, when operating
+         * in WPA3-Personal transition mode a STA:
+         *
+         * - should allow AKM suite selector: 00-0F-AC:6 (WPA-PSK-SHA256) to
+         *   be selected for an association;
+         * - shall negotiate PMF when associating to an AP using SAE.
+         *
+         * Those conditions are met when the interface has capabilities
+         * SAE, PMF, BIP.
+         *
+         * According to WPA3_Specification_v3.0 section 2.3, when operating
+         * in WPA3-Personal transition mode an AP:
+         *
+         * - shall set MFPC to 1, MFPR to 0.
+         *
+         * Therefore, do not operate in WPA3-Personal transition mode when PMF
+         * is set to disabled. This also provides a way to be compatible with
+         * some devices that are not fully compatible with WPA3-Personal
+         * transition mode.
+         */
+        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_SAE)
+            && _get_capability(priv, NM_SUPPL_CAP_TYPE_PMF)
+            && _get_capability(priv, NM_SUPPL_CAP_TYPE_BIP)
+            && (!is_ap || pmf != NM_SETTING_WIRELESS_SECURITY_PMF_DISABLE)) {
+            g_string_append(key_mgmt_conf, " SAE");
+            if (!is_ap && _get_capability(priv, NM_SUPPL_CAP_TYPE_FT))
+                g_string_append(key_mgmt_conf, " FT-SAE");
+        }
+
+    } else if (nm_streq(key_mgmt, "sae")) {
+        pmf = NM_SETTING_WIRELESS_SECURITY_PMF_REQUIRED;
+
+        g_string_append(key_mgmt_conf, "SAE");
+        if (!is_ap && _get_capability(priv, NM_SUPPL_CAP_TYPE_FT))
+            g_string_append(key_mgmt_conf, " FT-SAE");
+
+    } else if (nm_streq(key_mgmt, "wpa-eap")) {
+        if (pmf != NM_SETTING_WIRELESS_SECURITY_PMF_REQUIRED)
+            g_string_append(key_mgmt_conf, "WPA-EAP");
+        if (!is_ap && _get_capability(priv, NM_SUPPL_CAP_TYPE_FT)) {
+            g_string_append(key_mgmt_conf, " FT-EAP");
+            if (_get_capability(priv, NM_SUPPL_CAP_TYPE_SHA384))
+                g_string_append(key_mgmt_conf, " FT-EAP-SHA384");
+        }
+        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF)) {
+            g_string_append(key_mgmt_conf, " WPA-EAP-SHA256");
             if (_get_capability(priv, NM_SUPPL_CAP_TYPE_SUITEB192)
                 && pmf == NM_SETTING_WIRELESS_SECURITY_PMF_REQUIRED)
-                g_string_append(key_mgmt_conf, " wpa-eap-suite-b-192");
+                g_string_append(key_mgmt_conf, " WPA-EAP-SUITE-B-192");
         }
-        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_FT))
-            g_string_append(key_mgmt_conf, " ft-eap");
-        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_FT)
-            && _get_capability(priv, NM_SUPPL_CAP_TYPE_SHA384))
-            g_string_append(key_mgmt_conf, " ft-eap-sha384");
+
         switch (fils) {
         case NM_SETTING_WIRELESS_SECURITY_FILS_REQUIRED:
             g_string_truncate(key_mgmt_conf, 0);
             if (!_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF))
-                g_string_assign(key_mgmt_conf, "fils-sha256 fils-sha384");
+                g_string_assign(key_mgmt_conf, "FILS-SHA256 FILS-SHA384");
             /* fall-through */
         case NM_SETTING_WIRELESS_SECURITY_FILS_OPTIONAL:
-            if (_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF))
-                g_string_append(key_mgmt_conf, " fils-sha256 fils-sha384");
-            if (_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF)
-                && _get_capability(priv, NM_SUPPL_CAP_TYPE_FT))
-                g_string_append(key_mgmt_conf, " ft-fils-sha256");
-            if (_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF)
-                && _get_capability(priv, NM_SUPPL_CAP_TYPE_FT)
-                && _get_capability(priv, NM_SUPPL_CAP_TYPE_SHA384))
-                g_string_append(key_mgmt_conf, " ft-fils-sha384");
+            if (_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF)) {
+                g_string_append(key_mgmt_conf, " FILS-SHA256 FILS-SHA384");
+                if (!is_ap && _get_capability(priv, NM_SUPPL_CAP_TYPE_FT)) {
+                    g_string_append(key_mgmt_conf, " FT-FILS-SHA256");
+                    if (_get_capability(priv, NM_SUPPL_CAP_TYPE_SHA384))
+                        g_string_append(key_mgmt_conf, " FT-FILS-SHA384");
+                }
+            }
             break;
+
         default:
             break;
         }
-    } else if (nm_streq(key_mgmt, "sae")) {
-        if (_get_capability(priv, NM_SUPPL_CAP_TYPE_FT))
-            g_string_append(key_mgmt_conf, " ft-sae");
+
     } else if (nm_streq(key_mgmt, "wpa-eap-suite-b-192")) {
         pmf = NM_SETTING_WIRELESS_SECURITY_PMF_REQUIRED;
-        if (!nm_supplicant_config_add_option(self, "pairwise", "GCMP-256", -1, NULL, error)
-            || !nm_supplicant_config_add_option(self, "group", "GCMP-256", -1, NULL, error))
-            return FALSE;
+
+        g_string_append(key_mgmt_conf, "WPA-EAP-SUITE-B-192");
+        if (!is_ap && _get_capability(priv, NM_SUPPL_CAP_TYPE_FT)
+            && _get_capability(priv, NM_SUPPL_CAP_TYPE_SHA384))
+            g_string_append(key_mgmt_conf, " FT-EAP-SHA384");
     }
 
     if (!add_string_val(self, key_mgmt_conf->str, "key_mgmt", TRUE, NULL, error))
@@ -955,10 +1015,6 @@ nm_supplicant_config_add_setting_wireless_security(NMSupplicantConfig *
         }
     }
 
-    /* Don't try to enable PMF on non-WPA/SAE/OWE networks */
-    if (!NM_IN_STRSET(key_mgmt, "wpa-eap", "wpa-eap-suite-b-192", "wpa-psk", "sae", "owe"))
-        pmf = NM_SETTING_WIRELESS_SECURITY_PMF_DISABLE;
-
     /* Check if we actually support PMF */
     set_pmf = TRUE;
     if (!_get_capability(priv, NM_SUPPL_CAP_TYPE_PMF)) {
@@ -973,7 +1029,7 @@ nm_supplicant_config_add_setting_wireless_security(NMSupplicantConfig *
     }
 
     /* Only WPA-specific things when using WPA */
-    if (NM_IN_STRSET(key_mgmt, "wpa-psk", "wpa-eap", "sae", "owe")) {
+    if (NM_IN_STRSET(key_mgmt, "owe", "wpa-psk", "sae", "wpa-eap", "wpa-eap-suite-b-192")) {
         if (!ADD_STRING_LIST_VAL(self,
                                  setting,
                                  wireless_security,
@@ -985,29 +1041,40 @@ nm_supplicant_config_add_setting_wireless_security(NMSupplicantConfig *
                                  NULL,
                                  error))
             return FALSE;
-        if (!ADD_STRING_LIST_VAL(self,
-                                 setting,
-                                 wireless_security,
-                                 pairwise,
-                                 pairwise,
-                                 "pairwise",
-                                 ' ',
-                                 TRUE,
-                                 NULL,
-                                 error))
-            return FALSE;
-        if (!ADD_STRING_LIST_VAL(self,
-                                 setting,
-                                 wireless_security,
-                                 group,
-                                 groups,
-                                 "group",
-                                 ' ',
-                                 TRUE,
-                                 NULL,
-                                 error))
-            return FALSE;
 
+        if (nm_streq(key_mgmt, "wpa-eap-suite-b-192")) {
+            if (!nm_supplicant_config_add_option(self, "pairwise", "GCMP-256", -1, NULL, error))
+                return FALSE;
+            if (!nm_supplicant_config_add_option(self, "group", "GCMP-256", -1, NULL, error))
+                return FALSE;
+        } else {
+            if (!ADD_STRING_LIST_VAL(self,
+                                     setting,
+                                     wireless_security,
+                                     pairwise,
+                                     pairwise,
+                                     "pairwise",
+                                     ' ',
+                                     TRUE,
+                                     NULL,
+                                     error))
+                return FALSE;
+            if (!ADD_STRING_LIST_VAL(self,
+                                     setting,
+                                     wireless_security,
+                                     group,
+                                     groups,
+                                     "group",
+                                     ' ',
+                                     TRUE,
+                                     NULL,
+                                     error))
+                return FALSE;
+        }
+
+        /* We set the supplicants global "pmf" config value to "1" (optional),
+         * so no need to set it network-specific again if PMF_OPTIONAL is set.
+         */
         if (set_pmf
             && NM_IN_SET(pmf,
                          NM_SETTING_WIRELESS_SECURITY_PMF_DISABLE,
@@ -1026,10 +1093,10 @@ nm_supplicant_config_add_setting_wireless_security(NMSupplicantConfig *
     /* WEP keys if required */
     if (nm_streq(key_mgmt, "none")) {
         NMWepKeyType wep_type = nm_setting_wireless_security_get_wep_key_type(setting);
-        const char * wep0     = nm_setting_wireless_security_get_wep_key(setting, 0);
-        const char * wep1     = nm_setting_wireless_security_get_wep_key(setting, 1);
-        const char * wep2     = nm_setting_wireless_security_get_wep_key(setting, 2);
-        const char * wep3     = nm_setting_wireless_security_get_wep_key(setting, 3);
+        const char  *wep0     = nm_setting_wireless_security_get_wep_key(setting, 0);
+        const char  *wep1     = nm_setting_wireless_security_get_wep_key(setting, 1);
+        const char  *wep2     = nm_setting_wireless_security_get_wep_key(setting, 2);
+        const char  *wep3     = nm_setting_wireless_security_get_wep_key(setting, 3);
 
         if (!add_wep_key(self, wep0, "wep_key0", wep_type, error))
             return FALSE;
@@ -1107,22 +1174,29 @@ nm_supplicant_config_add_setting_wireless_security(NMSupplicantConfig *
         }
     }
 
+    wps_disabled = (nm_setting_wireless_security_get_wps_method(setting)
+                    == NM_SETTING_WIRELESS_SECURITY_WPS_METHOD_DISABLED);
+    if (wps_disabled) {
+        if (!nm_supplicant_config_add_option(self, "wps_disabled", "1", 1, NULL, error))
+            return FALSE;
+    }
+
     return TRUE;
 }
 
 static gboolean
-add_pkcs11_uri_with_pin(NMSupplicantConfig *       self,
-                        const char *               name,
-                        const char *               uri,
-                        const char *               pin,
+add_pkcs11_uri_with_pin(NMSupplicantConfig        *self,
+                        const char                *name,
+                        const char                *uri,
+                        const char                *pin,
                         const NMSettingSecretFlags pin_flags,
-                        GError **                  error)
+                        GError                   **error)
 {
     gs_strfreev char **split     = NULL;
-    gs_free char *     tmp       = NULL;
-    gs_free char *     tmp_log   = NULL;
-    gs_free char *     pin_qattr = NULL;
-    char *             escaped   = NULL;
+    gs_free char      *tmp       = NULL;
+    gs_free char      *tmp_log   = NULL;
+    gs_free char      *pin_qattr = NULL;
+    char              *escaped   = NULL;
 
     if (uri == NULL)
         return TRUE;
@@ -1158,25 +1232,25 @@ add_pkcs11_uri_with_pin(NMSupplicantConfig *       self,
 
 gboolean
 nm_supplicant_config_add_setting_8021x(NMSupplicantConfig *self,
-                                       NMSetting8021x *    setting,
-                                       const char *        con_uuid,
+                                       NMSetting8021x     *setting,
+                                       const char         *con_uuid,
                                        guint32             mtu,
                                        gboolean            wired,
-                                       GError **           error)
+                                       GError            **error)
 {
-    NMSupplicantConfigPrivate *priv;
-    char *                     tmp;
-    const char *               peapver, *value, *path;
-    gboolean                   added;
-    GString *                  phase1, *phase2;
-    GBytes *                   bytes;
-    gboolean                   fast = FALSE;
-    guint32                    i, num_eap;
-    gboolean                   fast_provisoning_allowed = FALSE;
-    const char *               ca_path_override = NULL, *ca_cert_override = NULL;
-    guint32                    frag, hdrs;
-    gs_free char *             frag_str = NULL;
-    NMSetting8021xAuthFlags    phase1_auth_flags;
+    NMSupplicantConfigPrivate    *priv;
+    char                         *tmp;
+    const char                   *peapver, *value, *path;
+    gboolean                      added;
+    GString                      *phase1, *phase2;
+    GBytes                       *bytes;
+    gboolean                      fast = FALSE;
+    guint32                       i, num_eap;
+    gboolean                      fast_provisoning_allowed = FALSE;
+    const char                   *ca_path_override = NULL, *ca_cert_override = NULL;
+    guint32                       frag, hdrs;
+    gs_free char                 *frag_str = NULL;
+    NMSetting8021xAuthFlags       phase1_auth_flags;
     nm_auto_free_gstring GString *eap_str = NULL;
 
     g_return_val_if_fail(NM_IS_SUPPLICANT_CONFIG(self), FALSE);
