@@ -1097,21 +1097,6 @@ nm_platform_lookup_object_by_addr_family(NMPlatform   *platform,
 
 /*****************************************************************************/
 
-static inline gboolean
-nmp_object_get_assume_config_once(const NMPObject *obj)
-{
-    switch (NMP_OBJECT_GET_TYPE(obj)) {
-    case NMP_OBJECT_TYPE_IP4_ADDRESS:
-    case NMP_OBJECT_TYPE_IP6_ADDRESS:
-        return NMP_OBJECT_CAST_IP_ADDRESS(obj)->a_assume_config_once;
-    case NMP_OBJECT_TYPE_IP4_ROUTE:
-    case NMP_OBJECT_TYPE_IP6_ROUTE:
-        return NMP_OBJECT_CAST_IP_ROUTE(obj)->r_assume_config_once;
-    default:
-        return nm_assert_unreachable_val(FALSE);
-    }
-}
-
 static inline gboolean
 nmp_object_get_force_commit(const NMPObject *obj)
 {
